@@ -1,18 +1,22 @@
 import logging
 from random import randint
 
+from demo.windows import second_window, third_window
 from events import Events
 
 from aio_wx_widgets.controller import BaseController
-from demo.windows import second_window, third_window
 
 _LOGGER = logging.getLogger(__name__)
 
 
 class ControllerOne(BaseController):
+    float_val: float = 0
+
     def __init__(self, model):
-        self.value_1: int = 0
-        self.a_string_value = "A certain string"
+        # self.float_val: float = 0
+        self.int_val: int = 987
+        self.a_string_value = None
+        self.a_checkbox_value: bool = True
         super().__init__(model)
 
         self.add_to_log = Events()
@@ -32,4 +36,8 @@ class ControllerOne(BaseController):
     async def set_value(self):
         val = randint(1, 100)
         _LOGGER.debug("Setting bound property to %s", val)
-        self.value_1 = val
+        self.int_val = val
+
+    @property
+    def value(self):
+        return 10
